/******************************************************************************
*
* Name:     I2C_BF5xx_rev07.h
*
*******************************************************************************
*
* (C) Copyright 2003 - 2006 - Analog Devices, Inc.  All rights reserved.
*
*Project Name:      I2C programming via PF pins under assembly code
*
*Author:            $Author: ANALOG\tlorenz $
*
*Group:             ADI Systems Engineering Munich
*
*Revision:          $Revision: 0.8 $
*
*Last Modified:     $Date:  02/07/2008$
*
*History:           0.1     01/15/2001  initial release                     TL
*                   0.2     06/06/2003  added support for BF561             GO
*                   0.3     08/25/2004  avoid master/slave driver confliced TL
*                   0.4     10/04/2006  adding error handling               KU
*                                       adding 16bit adddr/data support     KU
*                   0.5     11/01/2006  added derivative independance       TL
*                   0.6     12/04/2006  test run on different EZ-KITs       TL
*                                       "ADVs, Micron, Kodak, Omnivision"   TL
*                   0.7     12/13/2006  added coding style and end test     TL
*                   0.8     02/07/2008  added core selection (COREA/COREB)  KU/TL
*
*Software:          VisualDSP++4.5 (February Update 2007)
*
*Hardware:          ADSP-BF561 EZ-KIT LITE REV 2.0 ADSP-BF561 Chip REV 0.5
*                   ADSP-BF533 EZ-KIT LITE REV 1.7 ADSP-BF533 Chip REV 0.4
*
*Connections:       ADDS-HPUSB-ICE
*
*Registers used:    R7-R0, P5-P0
*
*Settings:
*
*Purpose:           I2C Protocol State Machine (SCCB software interface)
*                   This protocol allows to program I2C devices by
*                   Blackfin derivatives via PF pins (GPIOs). It can either be
*                   used for assembly projects or for C projects.
*
******************************************************************************/

/******************************************************************************
 Include Section
******************************************************************************/
#ifdef __ADSPBF561__
#include <defbf561.h>
/*************** SCCB constants **********************************************/
// Statically IVG10 is used (default state)! No changes to SIC_IARx
#define ISR_SCCB_Timer              0xFFE02028      // address of the Event Vector Table Register (EVT)
#define System_MMR_High_Address     0xFFC00000      // the high address word is handled like pages
#define Core_MMR_High_Address       0xFFE00000      // the high address word is handled like pages
#define SCL_PERIOD                  0x80            // 0x80 = scl_period ~= 320kHz at 120MHz SYSCLK
// #define SCL_PERIOD               0x200           // scl_period >= 133MHz/(3 x 0.4MHz)
#define SCL_HIGH SCL_PERIOD         >> 1            // Ratio between timer period and width
#define SCL                         0x1             // serial clock is PF1
#define SDA                         0x2             // serial data is PF0
#define scl_bit                     0               // scl = PF1
#define sda_bit                     1               // sda = PF0

//  Hardware description 
#define COREA
#define FIO_FLAG_D                  FIO0_FLAG_D     // select PF pins to use
#define FIO_FLAG_C                  FIO0_FLAG_C
#define FIO_FLAG_S                  FIO0_FLAG_S
#define FIO_DIR                     FIO0_DIR
#define FIO_INEN                    FIO0_INEN

#define TIMER_STATUS_REGISTER       TMRS8_STATUS    // selected timer status register addr
#define TIMER_DISABLE_REGISTER      TMRS8_DISABLE   // selected timer disable register addr
#define TIMER_ENABLE_REGISTER       TMRS8_ENABLE    // selected timer enable register addr
#define TIMER_CONFIG_REGISTER       TIMER0_CONFIG   // selected timer config register addr
#define TIMER_PERIOD_REGISTER       TIMER0_PERIOD   // selected timer period register addr
#define TIMER_WIDTH_REGISTER        TIMER0_WIDTH    // selected timer width register addr

#if defined(COREA)
#define SIC_IMASKx					SICA_IMASK1
#elif defined(COREB)  
#define SIC_IMASKx					SICB_IMASK1
#else
#error YOU NEED TO DEFINE COREA or COREB
#endif

#define TIMER_CONFIG_SET            0x025D          // set the timer configurations
#define TIMER_INTERRUPT_SERVICE     0x0011          // service the timer interrupt in the status register
#define TIMER_INTERRUPT_SERVICE_END 0x1011          // service and stop the timer in the status register
#define TIMER_ENABLE_BIT            0x0001          // timer enable bit (dedicated to a timer)
#define TIMER_DISABLE_BIT           0x0001          // timer disable bit (dedicated to a timer)
#define SIC_IMASKx_BIT              3               // select a timer to pass the SIC_IMASKx register
#define IVEC_SELECT                 10              // enable the interrupt at the core IMASK register
#endif
/*****************************************************************************/





#ifdef __ADSPBF533__
#include <defBF533.h>
/*************** SCCB Constants  *********************************************/
// Statically IVG11 is used (default state)! No changes to SIC_IARx
#define ISR_SCCB_Timer              0xFFE0202C      //Address of the interrupt register
#define System_MMR_High_Address     0xFFC00000      //The high address word is handled like pages
#define Core_MMR_High_Address       0xFFE00000      //The high address word is handled like pages
#define SCL_PERIOD                  0x80            // scl_period >= 133MHz/(3 x 0.4MHz)
#define SCL_HIGH SCL_PERIOD         >> 1            // Ratio between timer period and width
#define SCL                         0x1             // serial clock is PF0
#define SDA                         0x2             // serial data is PF1
#define scl_bit                     0               // scl = PF0
#define sda_bit                     1               // sda = PF1

//  Hardware description 
#define TIMER_STATUS_REGISTER       TIMER_STATUS    // selected timer status register addr
#define TIMER_DISABLE_REGISTER      TIMER_DISABLE   // selected timer disable register addr
#define TIMER_ENABLE_REGISTER       TIMER_ENABLE    // selected timer enable register addr
#define TIMER_CONFIG_REGISTER       TIMER0_CONFIG   // selected timer config register addr
#define TIMER_PERIOD_REGISTER       TIMER0_PERIOD   // selected timer period register addr
#define TIMER_WIDTH_REGISTER        TIMER0_WIDTH    // selected timer width register addr
#define SIC_IMASKx                  SIC_IMASK       // selected system interrupt controller IMASK register
#define TIMER_CONFIG_SET            0x025D          // set the timer configurations
#define TIMER_INTERRUPT_SERVICE     0x0011          // service the timer interrupt in the status register
#define TIMER_INTERRUPT_SERVICE_END 0x1011          // service and stop the timer in the status register
#define TIMER_ENABLE_BIT            0x0001          // timer enable bit (dedicated to a timer)
#define TIMER_DISABLE_BIT           0x0001          // timer disable bit (dedicated to a timer)
#define SIC_IMASKx_BIT              16              // select a timer to pass the SIC_IMASKx register
#define IVEC_SELECT                 11              // enable the interrupt at the core IMASK register
#endif
/*****************************************************************************/

